ClearButton constructor
const
ClearButton(
- TextEditingController _controller, {
- Widget icon = defaultIcon,
- Key? key,
Constructor for the ClearButton class.
- TextEditingController is the text editing controller to listen to.
iconis the icon to display in the button.keyis the optional key to use for the widget.
Implementation
const ClearButton(this._controller, {this.icon = defaultIcon, super.key});