iconSize property
The size of the icon inside the button.
If null, uses IconThemeData.size. If it is also null, the default size is 24.0.
The size given here is passed down to the widget in the icon property
via an IconTheme. Setting the size here instead of in, for example, the
Icon.size property allows the IconButton to size the splash area to
fit the Icon. If you were to set the size of the Icon using
Icon.size instead, then the IconButton would default to 24.0 and then
the Icon itself would likely get clipped.
This property is only used when icon is or contains an Icon widget. It will be
ignored if other widgets are used, such as an Image.
If ThemeData.useMaterial3 is set to true and this is null, the size of the
IconButton would default to 24.0. The size given here is passed down to the
ButtonStyle.iconSize property.
Implementation
final double? iconSize;