splashColor property
The primary color of the button when the button is in the down (pressed) state.
The splash is represented as a circular overlay that appears above the
highlightColor overlay. The splash overlay has a center point that matches
the hit point of the user touch event. The splash overlay will expand to
fill the button area if the touch is held for long enough time. If the splash
color has transparency then the highlight and button color will show through.
If ThemeData.useMaterial3 is set to true, this will not be used. Use
highlightColor instead to show the overlay color of the button when the button
is in the pressed state.
Defaults to the Theme's splash color, ThemeData.splashColor.
Implementation
final Color? splashColor;