BlocASEAN class final

Represents the Association of Southeast Asian Nations.

Inheritance

Constructors

BlocASEAN()
Creates an instance of the Association of Southeast Asian Nations.
const

Properties

acronym → String
The acronym of the bloc.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the bloc.
finalinherited
otherAcronyms → List<String>?
Other acronyms of the regional bloc.
finalinherited
otherNames → List<String>?
Other names of the regional bloc.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool short = true}) → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited