CountryTile typedef

CountryTile = IsoTile<WorldCountry>

A typedef for an IsoTile specialized for WorldCountry items.

Used in CountryPicker and PhoneCodePicker to display country list items with their properties such as name, flag, code, and phone code.

Implementation

typedef CountryTile = IsoTile<WorldCountry>;