Ellipse class final

A class representing an ellipse shape.

Ellipses are used in flags to represent various symbolic meanings and can be used as part of the flag's design.

Implemented types

Constructors

Ellipse()
Creates a new instance of Ellipse.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited