IddExtension extension

Provides extension methods for Idd class. Contains common methods for example copyWith, toMap, fromMap, etc, that are common to all package's submodels.

on

Properties

hasSingleSuffix bool

Available on Idd, provided by the IddExtension extension

Returns true if this Idd object has a single suffix value.
no setter

Methods

copyWith({int? root, List<int>? suffixes}) Idd

Available on Idd, provided by the IddExtension extension

Creates a copy of this object with the given fields replaced with the new values.
phoneCode({String leading = "+", bool isRtl = false}) String

Available on Idd, provided by the IddExtension extension

Returns a string representation of the phone code for this Idd object.
toMap() JsonObjectMap

Available on Idd, provided by the IddExtension extension

Converts this object object to a JSON like map.

Static Methods

fromMap(JsonMap map) Idd

Available on Idd, provided by the IddExtension extension

Creates a new instance of this object from a JSON like map.