ListItemTile<T extends Object> class

A custom list tile widget that displays a list item.

Inheritance
Implementers
Available extensions

Constructors

ListItemTile(T item, {ValueSetter<T>? onPressed, bool excludeSemantics = true, String? semanticsIdentifier, Widget? chosenIcon = const Icon(Icons.beenhere_outlined), bool isChosen = false, bool isDisabled = false, bool autofocus = false, EdgeInsetsGeometry? contentPadding, bool? dense, bool? enableFeedback, Color? focusColor, FocusNode? focusNode, double? horizontalTitleGap, Color? hoverColor, Color? iconColor, bool internalAddSemanticForOnTap = true, bool? isThreeLine, Key? key, Widget? leading, TextStyle? leadingAndTrailingTextStyle, double? minLeadingWidth, double? minTileHeight, double? minVerticalPadding, MouseCursor? mouseCursor, ValueChanged<bool>? onFocusChange, GestureLongPressCallback? onLongPress, Color? selectedColor, Color? selectedTileColor, ShapeBorder? shape, Color? splashColor, ListTileStyle? style, Widget? subtitle, TextStyle? subtitleTextStyle, Color? textColor, Color? tileColor, Widget? title, ListTileTitleAlignment? titleAlignment, TextStyle? titleTextStyle, VisualDensity? visualDensity, MaterialStatesController? statesController})
Constructor for the ListItemTile class.
const

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
chosenIcon → Widget?

Available on ListItemTile<T>, provided by the ListItemTileExtension extension

The icon to display when the tile is selected.
no setter
contentPadding → EdgeInsetsGeometry?
The tile's internal padding.
finalinherited
dense → bool?
Whether this list tile is part of a vertically dense list.
finalinherited
enabled → bool
Whether this list tile is interactive.
finalinherited
enableFeedback → bool?
Whether detected gestures should provide acoustic and/or haptic feedback.
finalinherited
excludeSemantics → bool
Whether to exclude subtitle and leading from semantics tree.
final
focusColor → Color?
The color for the tile's Material when it has the input focus.
finalinherited
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
horizontalTitleGap → double?
The horizontal gap between the titles and the leading/trailing widgets.
finalinherited
hoverColor → Color?
The color for the tile's Material when a pointer is hovering over it.
finalinherited
iconColor → Color?
Defines the default color for leading and trailing icons.
finalinherited
internalAddSemanticForOnTap → bool
Whether to add button:true to the semantics if onTap is provided. This is a temporary flag to help changing the behavior of ListTile onTap semantics.
finalinherited
isChosen → bool

Available on ListItemTile<T>, provided by the ListItemTileExtension extension

A boolean indicating whether the tile is selected (or marked as favorite).
no setter
isDisabled → bool

Available on ListItemTile<T>, provided by the ListItemTileExtension extension

A boolean indicating whether the tile is disabled.
no setter
isThreeLine → bool?
Whether this list tile is intended to display three lines of text.
finalinherited
item → T
The item to display in the list tile.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
A widget to display before the title.
finalinherited
leadingAndTrailingTextStyle → TextStyle?
The text style for ListTile's leading and trailing.
finalinherited
minLeadingWidth → double?
The minimum width allocated for the ListTile.leading widget.
finalinherited
minTileHeight → double?
The minimum height allocated for the ListTile widget.
finalinherited
minVerticalPadding → double?
The minimum padding on the top and bottom of the title and subtitle widgets.
finalinherited
mouseCursor → MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
finalinherited
onFocusChange → ValueChanged<bool>?
Handler called when the focus changes.
finalinherited
onLongPress → GestureLongPressCallback?
Called when the user long-presses on this list tile.
finalinherited
onPressed → ValueSetter<T>?
The callback function to call when the tile is pressed.
final
onTap → GestureLongPressCallback?
Called when the user taps this list tile.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
If this tile is also enabled then icons and text are rendered with the same color.
finalinherited
selectedColor → Color?
Defines the color used for icons and text when the list tile is selected.
finalinherited
selectedTileColor → Color?
Defines the background color of ListTile when selected is true.
finalinherited
semanticsIdentifier → String?
Optional string that describes the node for UI automation tools that work by querying the accessibility hierarchy, such as Android UI Automator, iOS XCUITest, or Appium. It's not exposed to users.
final
shape → ShapeBorder?
Defines the tile's InkWell.customBorder and Ink.decoration shape.
finalinherited
splashColor → Color?
The color of splash for the tile's Material.
finalinherited
statesController → MaterialStatesController?
Represents the interactive "state" of this widget in terms of a set of WidgetStates, like WidgetState.pressed and WidgetState.focused.
finalinherited
style → ListTileStyle?
Defines the font used for the title.
finalinherited
subtitle → Widget?
Additional content displayed below the title.
finalinherited
subtitleTextStyle → TextStyle?
The text style for ListTile's subtitle.
finalinherited
textColor → Color?
Defines the text color for the title, subtitle, leading, and trailing.
finalinherited
tileColor → Color?
Defines the background color of ListTile when selected is false.
finalinherited
title → Widget?
The primary content of the list tile.
finalinherited
titleAlignment → ListTileTitleAlignment?
Defines how ListTile.leading and ListTile.trailing are vertically aligned relative to the ListTile's titles (ListTile.title and ListTile.subtitle).
finalinherited
titleTextStyle → TextStyle?
The text style for ListTile's title.
finalinherited
trailing → Widget?
A widget to display after the title.
finalinherited
visualDensity → VisualDensity?
Defines how compact the list tile's layout will be.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fontSize → const double
Default font size.