LocaleEntry typedef
A typedef representing a map entry of Locale and TypedLocale.
The LocaleEntry typedef is a shorthand for MapEntry<Locale, TypedLocale> type. It defines a map entry where the key is of type Locale and the value is of type TypedLocale.
Example usage:
const localeEntry = LocaleEntry(Locale('en'), TypedLocale(LangEng()));
Implementation
typedef LocaleEntry = MapEntry<Locale, TypedLocale>;