regExpPattern property

String regExpPattern
final

The regular expression pattern for this PostalCode object.

The regExpPattern string specifies a regular expression pattern that can be used to validate postal codes. The regular expression should include a single capturing group that matches the entire postal code.

Implementation

final String regExpPattern;