ProgrammingLanguage class

A class that represents a programming language.

A programming language is a formal language that is used to write computer programs. Examples of programming languages include C++, Java, Python, Dart.

Inheritance

Constructors

ProgrammingLanguage({required String name, bool isCompiled = true, bool isLowLevel = false})
Creates a new instance of the ProgrammingLanguage class.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCompiled → bool
Whether the programming language is compiled.
final
isLowLevel → bool
Whether the programming language is low-level.
final
name → String
The name of the language.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool short = true}) → String
Returns a string representation of this ProgrammingLanguage object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited