toString method
Returns a string representation of this ProgrammingLanguage object.
The optional short parameter specifies whether to use a short format
(defaults to true). If short is true, this method returns the same
string as the Language.toString method. If short is false, this
method returns a string that includes the isCompiled and isLowLevel
properties of the programming language.
Implementation
@override
String toString({bool short = true}) => short
? super.toString()
: 'ProgrammingLanguage(name: "$name", isCompiled: $isCompiled, '
"isLowLevel: $isLowLevel)";