crossAxisAlignment property
How the items should be placed along the cross axis.
For example, CrossAxisAlignment.center, the default, centers the children in the cross axis.
Implementation
@override
final CrossAxisAlignment? crossAxisAlignment;
How the items should be placed along the cross axis.
For example, CrossAxisAlignment.center, the default, centers the children in the cross axis.
@override
final CrossAxisAlignment? crossAxisAlignment;