StatefulSearchable<T extends Object> class abstract

An abstract stateful widget that provides search functionality.

Inheritance
Implemented types
Implementers

Constructors

StatefulSearchable({required SearchData searchIn(T item, BuildContext context), required TextEditingController textController, bool caseSensitiveSearch = false, bool startWithSearch = true, Iterable<T> onSearchResultsBuilder(String query, SearchMap<T> map)?, Key? key})
Constructor for the StatefulSearchable class.
const

Properties

caseSensitiveSearch bool
A boolean indicating whether the search should be case-sensitive.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSearchResultsBuilder Iterable<T> Function(String query, SearchMap<T> map)?
A function that takes a query (usually user typed input) and a map of items to their search strings and returns an iterable of items that match the query. Useful for customizing the search results with different search algorithms.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchIn SearchData Function(T item, BuildContext context)
A function that takes an item and context and returns SearchData to search in.
final
startWithSearch bool
A boolean indicating whether the search field should only search by starting with the search string.
final
textController TextEditingController
The text editing controller for the search bar.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited