WorldCountryWebResources extension

Provides extension methods for accessing web resources related to a WorldCountry object.

on

Methods

flagPngUrl() → String

Available on WorldCountry, provided by the WorldCountryWebResources extension

Returns the URL of the PNG image file for the country's flag.
flagSvgUrl() → String

Available on WorldCountry, provided by the WorldCountryWebResources extension

Returns the URL of the SVG image file for the country's flag.
maybeCoatOfArmsPngUrl() → String?

Available on WorldCountry, provided by the WorldCountryWebResources extension

Returns the URL of the PNG image file for the country's coat of arms if it has one, or null otherwise.
maybeCoatOfArmsSvgUrl() → String?

Available on WorldCountry, provided by the WorldCountryWebResources extension

Returns the URL of the SVG image file for the country's coat of arms if it has one, or null otherwise.

Constants

png → const String
The file extension for PNG images.
svg → const String
The file extension for SVG images.