smallSimplifiedFlagsMap top-level constant

Map<WorldCountry, BasicFlag> const smallSimplifiedFlagsMap

A map that associates country objects with simplified flag representations.

This map is used to provide simplified flag representations for various countries. Each entry in the map consists of a country as the key and a country flag as the value.

Example usage:

final usaFlag = smallSimplifiedFlagsMap[const CountryUsa()];

Implementation

const smallSimplifiedFlagsMap = <WorldCountry, BasicFlag>{
  ...uniqueSimplifiedFlagsMap,
  ...smallSimplifiedAlternativeFlagsMap,
};