MaybeWidget<T extends Object> class
A widget that does a null-check of provided value and returns orElse
(default to SizedBox.shrink) if value is null.
Otherwise provides a builder with a non-null value.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MaybeWidget
- Annotations
Constructors
- MaybeWidget(T? value, Widget _builder(T), {Widget orElse = const SizedBox.shrink(), bool buildWhen(T)?, Key? key})
-
Constructor for the MaybeWidget class.
const
- MaybeWidget.identifiable(T? value, Widget _builder(T), {Widget orElse = const SizedBox.shrink(), bool buildWhen(T)?, Key? key})
- Identifiable constructor for the MaybeWidget class.
- MaybeWidget.offstage(T? value, Widget _builder(T), {Widget orElse = const Offstage(), bool buildWhen(T)?, Key? key})
-
Creates a MaybeWidget that uses Offstage as the default
orElsewidget.const
Properties
- buildWhen → bool Function(T)?
-
Optional predicate that must return
truefor the builder to be used.final - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- orElse → Widget
-
The widget to display if value is null.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T?
-
The value to check for null.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
list<
T extends Object> (T? value, {Widget? child(T)?, Iterable< Widget?> children(T)?, bool buildWhen(T value)?}) → List<Widget> - Creates a list of widgets based on a nullable value.
-
orNull<
W extends Widget, T extends Object> (T? value, W? builder(T)?, {bool buildWhen(T value)?}) → W? -
Conditional widget builder that returns
nullwhenvalueisnull.