BaseTileThemeData<T extends IsoTranslated<TranslatedName, Object, BasicLocale> > class
base
A theme extension data class that holds theme data for base tiles.
This class defines the visual properties of base tile widgets in an app and
allows for theming customizations specific to tiles that display translated
content. It extends ThemeExtension to facilitate the ease of creating
extendable theme data.
The generic type T extends from IsoTranslated and represents the model
that contains translated text information which the tile will use.
Parameters:
itemBuilder: An optional function that returns a widget for a given set of ItemProperties and the default IsoTile widget.
This allows for custom tile widgets to be built based on the provided item properties and whether the tile should be dense or not.
- Implementers
- Annotations
Constructors
-
BaseTileThemeData({Widget? itemBuilder(ItemProperties<
T> , IsoTile<T> )?}) -
Creates a BaseTileThemeData with the given properties.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemBuilder
→ Widget? Function(ItemProperties<
T> , IsoTile<T> )? -
A builder function that takes ItemProperties and a default tile widget,
and returns a widget for the tile.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{Widget? itemBuilder(ItemProperties< T> , IsoTile<T> )?}) → BaseTileThemeData<T> - Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
-
lerp(
covariant ThemeExtension< BaseTileThemeData< ? other, double t) → BaseTileThemeData<T> >T> -
Linearly interpolate with another
ThemeExtensionobject. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited