DualFlagClipper class
A CustomClipper that clips to one side of a line through the center at the given angle.
0or360degrees: clips to the top half90or-270degrees: clips to the left half180or-180degrees: clips to the bottom half270or-90degrees: clips to the right half- Other values: clips along the angled line through the center.
- Inheritance
-
- Object
- Listenable
- CustomClipper<
Path> - DualFlagClipper
- Annotations
Constructors
- DualFlagClipper([int angle = 45])
-
Creates a new instance of DualFlagClipper.
const
Properties
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to reclip.
inherited
-
getApproximateClipRect(
Size size) → Rect -
Returns an approximation of the clip returned by getClip, as
an axis-aligned Rect. This is used by the semantics layer to
determine whether widgets should be excluded.
inherited
-
getClip(
Size size) → Path -
Returns a description of the clip given that the render object being
clipped is of the given size.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to reclip.
inherited
-
shouldReclip(
covariant DualFlagClipper oldClipper) → bool -
Called whenever a new instance of the custom clipper delegate class is
provided to the clip object, or any time that a new clip object is created
with a new instance of the custom clipper delegate class (which amounts to
the same thing, because the latter is implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited