Idd class final
A class that represents an International Direct Dialing (IDD) code.
The Idd class is a simple value object that represents an International Direct Dialing (IDD) code. It consists of an int value that represents the root of the IDD code, and a List<int> value that represents the suffixes of the IDD code.
Example usage:
final idd = Idd(root: 3, suffixes: [81]);
print(idd); // Prints: 'Idd(root: 3, suffixes: [81])'
- Implemented types
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasSingleSuffix → bool
-
Available on Idd, provided by the IddExtension extension
Returnstrueif this Idd object has a single suffix value.no setter - root → int
-
The root of this IDD code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
suffixes
→ List<
int> -
The suffixes of this IDD code.
final
Methods
-
copyWith(
{int? root, List< int> ? suffixes}) → Idd -
Available on Idd, provided by the IddExtension extension
Creates a copy of this object with the given fields replaced with the new values. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
phoneCode(
{String leading = "+", bool isRtl = false}) → String -
Available on Idd, provided by the IddExtension extension
Returns a string representation of the phone code for this Idd object. -
toJson(
{JsonCodec codec = const JsonCodec()}) → String -
Returns a JSON-encoded string representation of the object.
override
-
toMap(
) → JsonObjectMap -
Available on Idd, provided by the IddExtension extension
Converts this object object to a JSON like map. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
covariant Idd other) → bool -
The equality operator.
override