IsoFlagExtension<T extends IsoStandardized<Object> , F extends BasicFlag> extension
An extension on IsoFlag to provide a copyWith method for creating a new instance of IsoFlag with modified properties.
- on
-
- IsoFlag<
T, F>
- IsoFlag<
Methods
-
copyWith(
{T? item, Map< T, F> ? map, Map<T, F> ? alternativeMap, Widget? orElse, double? height, double? width, double? aspectRatio, BoxDecoration? decoration, DecorationPosition? decorationPosition, EdgeInsetsGeometry? padding, FlagShaderDelegate? shader, Widget? child, Key? key}) → IsoFlag<T, F> -
Available on IsoFlag<
Creates a copy of this IsoFlag but with the given fields replaced with the new values.T, F> , provided by the IsoFlagExtension extension