IsoTranslated<T extends TranslatedName, N extends Object, L extends BasicLocale> class
abstract
interface
An abstract interface class that extends Translated and implements
IsoStandardized.
This class is used to represent a standardized ISO object that has been translated into multiple languages. It ensures that the item conforms to ISO standards and provides translations for the item's name.
The T type parameter represents the translated name of the item.
The N type parameter represents the name of the ISO object.
The L type parameter represents the basic locale used for localization.
- Implemented types
- Available extensions
Properties
- code → String
-
A string representing the ISO (usually a 3-letter) code for the object.
finalinherited
- codeOther → String
-
An string representing an alternative ISO code for the object.
This is typically used for short code (2-letter, as codeShort) or numeric
code (3-digit, as codeNumeric).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internationalName → String
-
An String representing the international name of the object. This is
typically a English name of the ISO object.
no setterinherited
-
l10n
→ BasicLocalizationDelegate<
L, T> -
Returns the BasicLocalizationDelegate used for handling translations.
no setter
- name → N
-
An object representing the name of the object.
finalinherited
-
namesNative
→ List<
N> ? -
An optional list of objects representing the native names of the object.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticIdentifier → String
-
Available on IsoStandardized<
Returns the semantic identifier for the ISO object, that can be used for example in the semantic widgets. It's being used in the default pickers. It's combination of the "ISO-" prefix and 3 letter uppercase alpha code.Object> , provided by the IsoSemanticsExtension extensionno setter
Methods
-
commonNameFor<
B extends L> (B mainLocale, {B? fallbackLocale, bool useLanguageFallback = true, String orElse = ""}) → String -
Available on IsoTranslated<
Returns a localized common name for this object.T, N, L> , provided by the TranslatedExtension extension -
mapWhenOrNull<
T extends Object> ({T? country(WorldCountry country)?, T? currency(FiatCurrency currency)?, T? language(NaturalLanguage language)?, T? script(Script script)?, T? orElse(IsoStandardized< Object> iso)?}) → T? -
Available on IsoStandardized<
Pattern-matching helper for ISO types.Object> ?, provided by the IsoStandardizedWorldCountryExtension extension -
maybeCommonNameFor<
B extends L> (B? mainLocale, {B? fallbackLocale, bool useLanguageFallback = true, String? orElse}) → String? -
Available on IsoTranslated<
Returns a localized common name for this object orT, N, L> , provided by the TranslatedExtension extensionnullif not found. -
namesCommonNative(
{String separator = "/", bool skipFirst = false, String? orElse}) → String -
Available on IsoTranslated<
Returns the common and native names of the ISO object as a single string.TranslatedName, Object, BasicLocale> , provided by the IsoTranslatedNamesExtension extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited