ScriptCopyWith<T extends Script> extension
- on
-
- T
Methods
-
copyWith(
{String? code, String? codeNumeric, String? date, String? name, String? pva}) → Script -
Available on T, provided by the ScriptCopyWith extension
Creates a copy of this object with the given fields replaced with the new values. If the new values arenull, the field is left unchanged. Otherwise, the field is replaced with the new value.