TranslatedNameExtension extension
Provides extension methods for TranslatedName class.
Contains common methods for example copyWith, toMap, fromMap, etc,
that are common to all package's submodels.
Properties
- asBasicLocale → BasicLocale
-
Available on TranslatedName, provided by the TranslatedNameExtension extension
Returns a BasicLocale object from this TranslatedName that represent locale of translation.no setter - common → String
-
Available on TranslatedName, provided by the TranslatedNameExtension extension
Just an alias for the name property.no setter
Methods
-
copyWith(
{String? countryCode, String? fullName, NaturalLanguage? language, String? name, Script? script}) → TranslatedName -
Available on TranslatedName, provided by the TranslatedNameExtension extension
Creates a copy of this object with the given fields replaced with the new values. -
toMap(
) → Map< String, String> -
Available on TranslatedName, provided by the TranslatedNameExtension extension
Converts this object object to a JSON like map.
Static Methods
-
fromMap(
JsonMap map) → TranslatedName -
Available on TranslatedName, provided by the TranslatedNameExtension extension
Creates a new instance of this object from a JSON like map.